@@ -7,7 +7,7 @@ function (object, process = c("Longitudinal", "Event"), include.splineCoefs = FA
         object$coefficients$betas
     } else {
         gammas <- object$coefficients$gammas
-        if (object$method %in% c("ch-GH", "ch-Laplace") && !include.splineCoefs) {
+        if (object$method == "ch-Laplace" && !include.splineCoefs) {
             ng <- length(gammas)
             nw <- ncol(object$x$W)
             gammas <- if (is.null(nw)) NULL else gammas[seq(ng - nw + 1, ng)]
@@ -15,6 +15,10 @@ function (object, process = c("Longitudinal", "Event"), include.splineCoefs = FA
         out <- c(gammas, "Assoct" = as.vector(object$coefficients$alpha))
         if (object$method == "weibull-AFT-GH")
             out <- - out
+        if ((lag <- object$y$lag) > 0) {
+            ii <- names(out) == "Assoct"
+            names(out)[ii] <- paste("Assoct(lag=", lag, ")", sep = "")
+        }
         out
     }
 }
